Re:ARMv7 vs. x86-64: Pathfinding benchmark of C++, D, Go, Ni...
by threeseed on Saturday December 20, 2014 @09:00AM
(#8776636)
Managed to get a 22% improvement on Core i7 OSX / Oracle JDK8 by replacing the for iterator-style loop with a C style one. Am I missing something because this shouldn't be faster.
Also add -Xbatch as a parameter which gives another few percentage points.
[ Parent
| on HN ]
Re:ARMv7 vs. x86-64: Pathfinding benchmark of C++, D, Go, Ni...
by super_tycoon on Saturday December 20, 2014 @09:16AM
(#8776667)
I refactored it to be more static and final/const. Also used an int[][] for the node data.
Original comment is on proggit. Went from 1600ms to 900ms.
http://www.reddit.com/r/programming/comments/2pvf68/armv7_vs...